import pytest
from src.main.python.ddadevops.domain import (
    DevopsFactory,
    Version,
    BuildType,
    MixinType,
)


def test_devops_factory():
    with pytest.raises(Exception):
        DevopsFactory().build_devops({"build_types": ["NOTEXISTING"]})

    with pytest.raises(Exception):
        DevopsFactory().build_devops(
            {
                "build_types": ["IMAGE"],
            }
        )

    sut = DevopsFactory().build_devops(
        {
            "stage": "test",
            "name": "mybuild",
            "module": "test_image",
            "project_root_path": "../../..",
            "build_types": ["IMAGE"],
            "mixin_types": [],
            "image_dockerhub_user": "dockerhub_user",
            "image_dockerhub_password": "dockerhub_password",
            "image_tag": "docker_image_tag",
        }
    )
    assert sut is not None
    assert sut.specialized_builds[BuildType.IMAGE] is not None

    sut = DevopsFactory().build_devops(
        {
            "stage": "test",
            "name": "mybuild",
            "module": "test_image",
            "project_root_path": "../../..",
            "build_types": ["C4K"],
            "mixin_types": [],
            "c4k_grafana_cloud_user": "user",
            "c4k_grafana_cloud_password": "password",
        },
        Version.from_str("1.0.0", "SNAPSHOT"),
    )
    assert sut is not None
    assert sut.specialized_builds[BuildType.C4K] is not None

    sut = DevopsFactory().build_devops(
        {
            "stage": "test",
            "name": "mybuild",
            "module": "test_image",
            "project_root_path": "../../..",
            "build_types": [],
            "mixin_types": ["RELEASE"],
            "release_main_branch": "main",
            "release_current_branch": "my_feature",
            "release_config_file": "project.clj",
        },
        Version.from_str("1.0.0", "SNAPSHOT"),
    )
    assert sut is not None
    assert sut.mixins[MixinType.RELEASE] is not None
