from pybuilder.core import Project
from pathlib import Path
from src.main.python.ddadevops.domain import (
    Validateable,
    DnsRecord,
    Devops,
    BuildType,
    MixinType,
    Version,
    ReleaseType,
    Release,
    Image,
)
from .helper import build_devops, devops_config


def test_sould_validate_release():
    sut = Release(
        devops_config(
            {
                "release_type": "MINOR",
                "release_current_branch": "main",
            }
        ),
        Version.from_str("1.3.1-SNAPSHOT", "SNAPSHOT"),
    )
    assert sut.is_valid()

    sut = Release(
        devops_config(
            {
                "release_type": "MINOR",
                "release_current_branch": "some-feature-branch",
            }
        ),
        Version.from_str("1.3.1-SNAPSHOT", "SNAPSHOT"),
    )
    assert not sut.is_valid()

    sut = Release(
        devops_config(
            {
                "release_primary_build_file": 1,
            }
        ),
        Version.from_str("1.3.1-SNAPSHOT", "SNAPSHOT"),
    )
    assert not sut.is_valid()


def test_sould_calculate_build_files():
    sut = Release(
        devops_config(
            {
                "release_type": "MINOR",
                "release_current_branch": "main",
                "release_primary_build_file": "project.clj",
                "release_secondary_build_files": ["package.json"],
            }
        ),
        Version.from_str("1.3.1-SNAPSHOT", "SNAPSHOT"),
    )
    assert ["project.clj", "package.json"] == sut.build_files()
